@@ -1,5 +1,5 @@
-#ifndef _ZNZLIB_H_
-#define _ZNZLIB_H_
+#ifndef ZNZLIB_H
+#define ZNZLIB_H
 
 /*
 znzlib.h  (zipped or non-zipped library)
@@ -47,6 +47,7 @@ extern "C" {
 #include <string.h>
 #include <stdarg.h>
 
+
 /* include optional check for HAVE_FDOPEN here, from deleted config.h:
 
    uncomment the following line if fdopen() exists for your compiler and
@@ -54,6 +55,18 @@ extern "C" {
 */
 /* #define HAVE_FDOPEN */
 
+#if defined(WIN32) || defined(WIN64) || defined(_WIN32) || defined(_WIN64) || defined(_MSVC) || defined(_MSC_VER)
+#include <io.h>
+#define fseek _fseeki64
+#define ftell _ftelli64
+#define znz_off_t long long
+#elif defined(__APPLE__) || defined(__FreeBSD__)
+#define znz_off_t off_t
+#else
+#include <unistd.h>
+#include <sys/types.h>
+#define znz_off_t off_t
+#endif
 
 #ifdef HAVE_ZLIB
 #if defined(ITKZLIB) && !defined(ITK_USE_SYSTEM_ZLIB)
@@ -97,11 +110,11 @@ size_t znzread(void* buf, size_t size, size_t nmemb, znzFile file);
 
 size_t znzwrite(const void* buf, size_t size, size_t nmemb, znzFile file);
 
-long znzseek(znzFile file, long offset, int whence);
+znz_off_t znzseek(znzFile file, znz_off_t offset, int whence);
 
 int znzrewind(znzFile stream);
 
-long znztell(znzFile file);
+znz_off_t znztell(znzFile file);
 
 int znzputs(const char *str, znzFile file);
 
